==> wave-reader-0.0.10.tar.gz: wave-reader-0.0.10/wave_reader/web/models/sensors_threshold_response_thresholds.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.sensor_threshold import SensorThreshold

T = TypeVar("T", bound="SensorsThresholdResponseThresholds")


@attr.s(auto_attribs=True)
class SensorsThresholdResponseThresholds:
    additional_properties: Dict[str, SensorThreshold] = attr.ib(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        sensors_threshold_response_thresholds = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = SensorThreshold.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        sensors_threshold_response_thresholds.additional_properties = (
            additional_properties
        )
        return sensors_threshold_response_thresholds

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> SensorThreshold:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: SensorThreshold) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> wave-reader-1.0.1.tar.gz: wave-reader-1.0.1/wave_reader/web/models/sensors_threshold_response_thresholds.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.sensor_threshold import SensorThreshold


T = TypeVar("T", bound="SensorsThresholdResponseThresholds")


@attr.s(auto_attribs=True)
class SensorsThresholdResponseThresholds:
    """ """

    additional_properties: Dict[str, "SensorThreshold"] = attr.ib(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:
        pass

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.sensor_threshold import SensorThreshold

        d = src_dict.copy()
        sensors_threshold_response_thresholds = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = SensorThreshold.from_dict(prop_dict)

            additional_properties[prop_name] = additional_property

        sensors_threshold_response_thresholds.additional_properties = (
            additional_properties
        )
        return sensors_threshold_response_thresholds

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "SensorThreshold":
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: "SensorThreshold") -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
